OC.L10N.register(
    "lib",
    {
    "Apps" : "Apps",
    "Help" : "सहयोग",
    "Personal" : "यक्तिगत",
    "Users" : "उपयोगकर्ता"
},
"nplurals=2; plural=(n != 1);");
